=================================
Flask ApiDoc
=================================
Flask ApiDoc is a Flask extension which adds support for the ApiDoc_.

|Version|

Features
===============
- Flask-Script command to generate the apidoc's files, by default they are generated into static/docs
- Host apidoc's files, by default they are hosted in http://localhost:5000/docs
- Replace the base URL for the endpoints by the current Flask URL.
- Allow absolute urls in @api

Documentation
===============
Soon... take a look at the example_ to see how it works.

Installation
===============
You can install flask-apidoc via Python Package Index (PyPI_),::

    $ pip install flask-apidoc

Feedback
===============
Please use the Issues_ for feature requests and troubleshooting usage.

.. |Version| image:: https://badge.fury.io/py/flask-apidoc.svg
   :target: http://badge.fury.io/py/flask-apidoc

.. _ApiDoc: http://www.apidocjs.com

.. _example: https://github.com/viniciuschiele/flask-apidoc/tree/master/example

.. _PyPi: https://pypi.python.org/pypi/flask-apidoc

.. _Issues: https://github.com/viniciuschiele/flask-apidoc/issues
